#
# spec file for package pulseaudio
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

%ifarch armv7 armv7hl
%define _lto_cflags %{nil}
%endif

#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir /var/adm/fillup-templates
%endif

%define drvver  15.0
%define soname  0
%define _udevrulesdir %(pkg-config --variable=udevdir udev)/rules.d
%define _bashcompletionsdir %{_datadir}/bash-completion/completions
Name:           pulseaudio
Version:        15.0
Release:        150400.4.2.2
Summary:        A Networked Sound Server
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
Group:          System/Sound Daemons
Url:            https://www.freedesktop.org/wiki/Software/PulseAudio/
Source:         https://www.freedesktop.org/software/pulseaudio/releases/%{name}-%{version}.tar.xz
Source1:        default.pa-for-gdm
Source2:        setup-pulseaudio
Source3:        sysconfig.sound-pulseaudio
Source5:        pulseaudio.service
Source6:        disable_flat_volumes.conf
Source7:        pulseaudio.tmpfiles
Source8:        pulseaudio-gdm-hooks.tmpfiles
Source9:        client-system.conf
Source10:       system-user-pulse.conf
Source98:       pulseaudio-rpmlintrc
Source99:       baselibs.conf
Patch0:         disabled-start.diff
Patch1:         suppress-socket-error-msg.diff
# PATCH-FIX-OPENSUSE qpaeq-shebang.patch Avoid rpmlint error due to using env python shebang
Patch5:         qpaeq-shebang.patch
# PATCH-FIX-OPENSUSE Workaround for old systemd on Leap 15.x
Patch6:         pulseaudio-old-systemd-workaround.patch
# PATCH-FIX-OPENSUSE Workaround for suse-module-tools directory
Patch7:         pulseaudio-dump-module-Ignore-invalid-module-init-tools.patch
BuildRequires:  alsa-devel >= 1.0.19
BuildRequires:  bluez-devel >= 5
BuildRequires:  fdupes
BuildRequires:  fftw3-devel >= 3.0
BuildRequires:  gcc-c++
BuildRequires:  jack-devel
BuildRequires:  meson
BuildRequires:  libatomic_ops-devel >= 1.2
BuildRequires:  libavahi-devel
BuildRequires:  libcap-devel
BuildRequires:  libopenssl-devel
BuildRequires:  libsndfile-devel >= 1.0.18
BuildRequires:  libtool
BuildRequires:  pkgconfig(libudev) >= 143
BuildRequires:  libwebrtc_audio_processing-devel >= 0.3
BuildRequires:  orc >= 0.4.9
BuildRequires:  perl-XML-Parser
BuildRequires:  pkgconfig
BuildRequires:  speexdsp-devel
BuildRequires:  systemd-rpm-macros
BuildRequires:  sysuser-tools
BuildRequires:  pkgconfig(bash-completion)
BuildRequires:  pkgconfig(check)
BuildRequires:  pkgconfig(dbus-1) >= 1.4.12
BuildRequires:  pkgconfig(gconf-2.0)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(ice)
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(lirc)
BuildRequires:  pkgconfig(sbc) >= 1.0
BuildRequires:  pkgconfig(sm)
BuildRequires:  pkgconfig(soxr)
BuildRequires:  pkgconfig(systemd)
BuildRequires:  pkgconfig(tdb)
BuildRequires:  pkgconfig(udev)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(x11-xcb)
BuildRequires:  pkgconfig(xcb)
BuildRequires:  pkgconfig(xtst)

Requires:       rtkit
Requires:       udev >= 146
#!BuildIgnore:  user(pulse)
Requires(pre):  user(pulse)
## needs the same liborc version which was used to build against
%requires_eq    liborc-0_4-0
Requires(post): pulseaudio-setup
Recommends:     alsa-plugins-pulse
Suggests:       libsoxr0 >= 0.1.1
Conflicts:      kernel < 2.6.31
Obsoletes:      libpulsecore9 < 0.9.15
Provides:       libpulsecore9 = 0.9.15
Obsoletes:      libpulsecore7 < 0.9.13
Provides:       libpulsecore7 = 0.9.13

Provides:       pulseaudio-daemon
Conflicts:      pulseaudio-daemon

%description
pulseaudio is a networked sound server for Linux, other Unix like
operating systems and Microsoft Windows. It is intended to be an
improved drop-in replacement for the Enlightened Sound Daemon (ESOUND).

%package setup
Summary:        Set-up script for PulseAudio
Group:          System/Sound Daemons
Requires(post): %fillup_prereq

%description setup
This package contains a setup script for making PulseAudio working with
various applications.

%package module-lirc
Summary:        LIRC module for PulseAudio
Group:          System/Sound Daemons
Requires:       %{name} = %{version}
Supplements:	(pulseaudio and lirc-core)

%description module-lirc
pulseaudio is a networked sound server for Linux and other Unix like
operating systems and Microsoft Windows. It is intended to be an
improved drop-in replacement for the Enlightened Sound Daemon (ESOUND).

This package provides support for IR and RF remotes.

%package module-x11
Summary:        X11 module for PulseAudio
Group:          System/Sound Daemons
Requires:       %{name} = %{version}
Requires:       %{name}-utils = %{version}

%description module-x11
pulseaudio is a networked sound server for Linux and other Unix like
operating systems and Microsoft Windows. It is intended to be an
improved drop-in replacement for the Enlightened Sound Daemon (ESOUND).

This package provides the components needed to automatically start
the PulseAudio sound server on X11 startup.

%package module-zeroconf
Summary:        Zeroconf module for PulseAudio
Group:          System/Sound Daemons
Requires:       %{name} = %{version}
Supplements:	(pulseaudio and avahi)

%description module-zeroconf
pulseaudio is a networked sound server for Linux and other Unix like
operating systems and Microsoft Windows. It is intended to be an
improved drop-in replacement for the Enlightened Sound Daemon (ESOUND).

This package provides zeroconf network support for the PulseAudio sound server

%package system-wide
Summary:        Support for running PulseAudio daemon system wide
Group:          System/Sound Daemons
Requires:       %{name}
%systemd_requires

%description system-wide
PulseAudio daemon can be run as a system-wide instance which than can be shared
by multiple local users. We recommend running the PulseAudio daemon per-user,
just like the traditional ESD sound daemon. In some situations however, such as
embedded systems where no real notion of a user exists, it makes sense to use
the system-wide mode.

Before you now go ahead and use it please read about what is wrong with system
mode:

http://www.freedesktop.org/wiki/Software/PulseAudio/Documentation/User/WhatIsWrongWithSystemWide

%package module-jack
Summary:        JACK support for the PulseAudio sound server
Group:          System/Sound Daemons
Requires:       %{name} = %{version}

%description module-jack
pulseaudio is a networked sound server for Linux and other Unix like
operating systems and Microsoft Windows. It is intended to be an
improved drop-in replacement for the Enlightened Sound Daemon (ESOUND).

This package includes support for Jack-based applications.

%package module-bluetooth
Summary:        Bluetooth support for the PulseAudio sound server
Group:          System/Sound Daemons
Requires:       %{name} = %{version}
Requires:       bluez >= 5
Supplements:	(pulseaudio and bluez)

%description module-bluetooth
pulseaudio is a networked sound server for Linux and other Unix like
operating systems and Microsoft Windows. It is intended to be an
improved drop-in replacement for the Enlightened Sound Daemon (ESOUND).

Contains Bluetooth audio (A2DP/HSP/HFP) support for the PulseAudio sound server.

%package module-gsettings
Summary:        GSettings module for PulseAudio
Group:          System/Sound Daemons
Requires:       %{name} = %{version}
Conflicts:      %{name}-module-gconf

%description module-gsettings
pulseaudio is a networked sound server for Linux and other Unix like
operating systems and Microsoft Windows. It is intended to be an
improved drop-in replacement for the Enlightened Sound Daemon (ESOUND).

This package provides GSettings storage of PulseAudio sound server settings.

%package -n libpulse%{soname}
Summary:        Client interface to PulseAudio
Group:          System/Libraries
Provides:       pulseaudio-libs = %{version}
Obsoletes:      pulseaudio-libs < %{version}

%description -n libpulse%{soname}
pulseaudio is a networked sound server for Linux and other Unix like
operating systems and Microsoft Windows. It is intended to be an
improved drop-in replacement for the Enlightened Sound Daemon (ESOUND).

This package contains the system libraries for clients of pulseaudio
sound server.

%package -n libpulse-mainloop-glib%{soname}
Summary:        GLIB 2.0 Main Loop wrapper for PulseAudio
Group:          System/Sound Daemons
Provides:       pulseaudio-libs-glib2 = %{version}
Obsoletes:      pulseaudio-libs-glib2 < %{version}

%description -n libpulse-mainloop-glib%{soname}
pulseaudio is a networked sound server for Linux and other Unix like
operating systems and Microsoft Windows. It is intended to be an
improved drop-in replacement for the Enlightened Sound Daemon (ESOUND).

This package contains the GLIB Main Loop bindings for the PulseAudio
sound server.

%package -n libpulse-devel
Summary:        Development package for the pulseaudio library
Group:          Development/Libraries/C and C++
Requires:       libpulse%{soname} = %{version}
Requires:       libpulse-mainloop-glib%{soname} = %{version}
Requires:       pkgconfig
Requires:       pkgconfig(glib-2.0)
Provides:       pulseaudio-devel = %{version}
Obsoletes:      pulseaudio-devel < %{version}

%description -n libpulse-devel
pulseaudio is a networked sound server for Linux and other Unix like
operating systems and Microsoft Windows. It is intended to be an
improved drop-in replacement for the Enlightened Sound Daemon (ESOUND).

This package contains the files needed to compile programs that use the
pulseaudio library.

%package utils
Summary:        PulseAudio utilities
Group:          System/Sound Daemons
Requires:       pulseaudio-daemon
Requires:       libpulse%{soname} = %{version}
Requires:       libpulse-mainloop-glib%{soname} = %{version}

%description utils
pulseaudio is a networked sound server for Linux and other Unix like
operating systems and Microsoft Windows. It is intended to be an
improved drop-in replacement for the Enlightened Sound Daemon (ESOUND).

This package provides utilies for making use of the PulseAudio sound
server.

%package gdm-hooks
Summary:        PulseAudio GDM integration
Group:          Productivity/Multimedia/Other
#avoid cycle
#!BuildIgnore:  gdm
Requires:       %{name} = %{version}
Requires:       gdm >= 2.22
Supplements:    (pulseaudio and gdm)
#for the gdm user
Requires(pre):  gdm

%description gdm-hooks
pulseaudio is a networked sound server for Linux and other Unix like
operating systems and Microsoft Windows. It is intended to be an
improved drop-in replacement for the Enlightened Sound Daemon (ESOUND).

This package contains GDM integration hooks for the PulseAudio sound server.

%package bash-completion
Summary:        PulseAudio Bash completion
Group:          System/Shells
Requires:       %{name}-utils = %{version}
Requires:       bash-completion
Supplements:    (pulseaudio and bash-completion)

%description bash-completion
Optional dependency offering bash completion for various PulseAudio utilities

%package zsh-completion
Summary:        PulseAudio zsh completion
Group:          System/Shells
Requires:       %{name}-utils = %{version}
Requires:       zsh
Supplements:    (pulseaudio and zsh)

%description zsh-completion
Optional dependency offering zsh completion for various PulseAudio utilities

%package -n system-user-pulse
Summary:        System user for PulseAudio
Group:          System/Base
Requires(pre):  group(audio)
BuildArch:      noarch
%sysusers_requires

%description -n system-user-pulse
System user for PulseAudio

%lang_package

%prep
%setup -q -T -b0
%patch0 -p1
%patch1 -p1
%patch5 -p1
# workaround for Leap 15.x
%if 0%{?suse_version} < 1550
%patch6 -p1
%endif
%patch7 -p1

%build
%meson \
      --auto-features=auto \
      -Dhal-compat=false   \
      -Dgsettings=enabled  \
      -Ddoxygen=false      \
      -Dsystem_user=pulse  \
      -Dsystem_group=pulse \
      -Daccess_group=pulse-access     \
      -Drunning-from-build-tree=false \
      -Dpulsedsp-location='%{_prefix}/\$LIB/pulseaudio' \
      -Dudevrulesdir="%{_udevrulesdir}"      \
      -Dsystemduserunitdir="%{_userunitdir}" \
      -Db_pie=true \
      %{nil}

%meson_build
%sysusers_generate_pre %{SOURCE10} pulseaudio system-user-pulse.conf

%install
%meson_install
rm -rf \
	"%{buildroot}%{_libdir}"/*.la \
	"%{buildroot}%{_libdir}/pulse-%{drvver}/modules"/*.la \
	"%{buildroot}%{_libdir}/pulseaudio"/*.la

# configure --disable-static had no effect; delete manually.
rm -rf "%{buildroot}%{_libdir}"/*.a

# system-wide service (optional)
install -D -m 0644 %{SOURCE5} %{buildroot}%{_unitdir}/%{name}.service
mkdir -p %{buildroot}%{_sbindir}
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rc%{name}

# some HW may get undetected without this (check pulseaudio 6.0RC1 announce)
ln -s default.conf %{buildroot}%{_datadir}/pulseaudio/alsa-mixer/profile-sets/extra-hdmi.conf

# remove xwayland.sessions.d files. Do we have such directory?
rm %{buildroot}%{_sysconfdir}/xdg/Xwayland-session.d/00-pulseaudio-x11

install %{SOURCE2} %{buildroot}%{_bindir}
chmod 755 %{buildroot}%{_bindir}/setup-pulseaudio
install -d %{buildroot}%{_fillupdir}
install -m 0644 %{SOURCE3} %{buildroot}%{_fillupdir}
mkdir -p %{buildroot}%{_sysconfdir}/profile.d
touch %{buildroot}%{_sysconfdir}/profile.d/pulseaudio.sh
touch %{buildroot}%{_sysconfdir}/profile.d/pulseaudio.csh
mkdir -p %{buildroot}%{_prefix}/lib/tmpfiles.d
install -m 644 %{SOURCE7} %{buildroot}%{_prefix}/lib/tmpfiles.d/pulseaudio.conf
install -m 644 %{SOURCE8} %{buildroot}%{_prefix}/lib/tmpfiles.d/pulseaudio-gdm-hooks.conf
mkdir -p %{buildroot}%{_prefix}/share/factory/var/lib/gdm/.pulse
install -m 644 %{SOURCE1} %{buildroot}%{_prefix}/share/factory/var/lib/gdm/.pulse/default.pa
# create .d conf dirs (since 8.0)
mkdir -p %{buildroot}%{_sysconfdir}/pulse/client.conf.d
install -m 0644 %{SOURCE9} %{buildroot}%{_sysconfdir}/pulse/client.conf.d/50-system.conf
mkdir -p %{buildroot}%{_sysconfdir}/pulse/daemon.conf.d
# create .d startup dirs (since 15.0)
mkdir -p %{buildroot}%{_sysconfdir}/pulse/default.pa.d
mkdir -p %{buildroot}%{_sysconfdir}/pulse/system.pa.d

# Install disable_flat_volumes.conf
install -m 0644 %{SOURCE6} %{buildroot}%{_sysconfdir}/pulse/daemon.conf.d/60-disable_flat_volumes.conf
# user
install -Dm0644 %{SOURCE10} %{buildroot}%{_sysusersdir}/system-user-pulse.conf
%find_lang %{name}

%pre -n system-user-pulse -f pulseaudio.pre

%post
/sbin/ldconfig
%tmpfiles_create pulseaudio.conf
if [ ! -f /etc/systemd/user/sockets.target.wants/%{name}.socket ]; then
  echo "Switching PulseAudio activation using systemd user socket."
  echo "Please log out from all sessions once to make it effective."
fi
%systemd_user_post pulseaudio.socket
# FIXME: workaround to make sure the user socket symlink creation (bsc#1083473)
if [ ! -f /etc/systemd/user/sockets.target.wants/%{name}.socket ]; then
  # below should work once when preset is defined properly:
  #  /usr/bin/systemctl --no-reload --global preset pulseaudio.socket
  mkdir -p /etc/systemd/user/sockets.target.wants
  ln -s %{_userunitdir}/%{name}.socket /etc/systemd/user/sockets.target.wants/%{name}.socket
fi
# Update the /etc/profile.d/pulseaudio.* files
setup-pulseaudio --auto > /dev/null

%preun
%systemd_user_preun pulseaudio.socket

%postun
/sbin/ldconfig
%systemd_user_postun pulseaudio.socket

%post   -n libpulse%{soname} -p /sbin/ldconfig
%postun -n libpulse%{soname} -p /sbin/ldconfig
%post   -n libpulse-mainloop-glib%{soname} -p /sbin/ldconfig
%postun -n libpulse-mainloop-glib%{soname} -p /sbin/ldconfig

%pre system-wide
%service_add_pre pulseaudio.service
exit 0

%post system-wide
%service_add_post pulseaudio.service
exit 0

%preun system-wide
%service_del_preun pulseaudio.service
exit 0

%postun system-wide
%service_del_postun pulseaudio.service
exit 0

%post setup
%{fillup_only -an sound}

%post gdm-hooks
%tmpfiles_create pulseaudio-gdm-hooks.conf

%files
%doc README
%license LICENSE GPL LGPL
%{_bindir}/pulseaudio
%{_bindir}/qpaeq
%dir %{_datadir}/pulseaudio
%{_datadir}/pulseaudio/alsa-mixer
%dir %{_libdir}/pulseaudio
%{_libdir}/pulseaudio/libpulsecore-%{drvver}.so
%dir %{_libdir}/pulse-%{drvver}/
%dir %{_libdir}/pulse-%{drvver}/modules/
%{_libdir}/pulse-%{drvver}/modules/libalsa-util.so
%{_libdir}/pulse-%{drvver}/modules/libcli.so
%{_libdir}/pulse-%{drvver}/modules/liboss-util.so
%{_libdir}/pulse-%{drvver}/modules/libprotocol-cli.so
%{_libdir}/pulse-%{drvver}/modules/libprotocol-http.so
%{_libdir}/pulse-%{drvver}/modules/libprotocol-native.so
%{_libdir}/pulse-%{drvver}/modules/libprotocol-simple.so
%{_libdir}/pulse-%{drvver}/modules/librtp.so
%{_libdir}/pulse-%{drvver}/modules/libwebrtc-util.so
%{_libdir}/pulse-%{drvver}/modules/module-alsa-card.so
%{_libdir}/pulse-%{drvver}/modules/module-alsa-sink.so
%{_libdir}/pulse-%{drvver}/modules/module-alsa-source.so
%{_libdir}/pulse-%{drvver}/modules/module-always-sink.so
%{_libdir}/pulse-%{drvver}/modules/module-always-source.so
%{_libdir}/pulse-%{drvver}/modules/module-allow-passthrough.so
%{_libdir}/pulse-%{drvver}/modules/module-augment-properties.so
%{_libdir}/pulse-%{drvver}/modules/module-card-restore.so
%{_libdir}/pulse-%{drvver}/modules/module-cli.so
%{_libdir}/pulse-%{drvver}/modules/module-cli-protocol-tcp.so
%{_libdir}/pulse-%{drvver}/modules/module-cli-protocol-unix.so
%{_libdir}/pulse-%{drvver}/modules/module-combine.so
%{_libdir}/pulse-%{drvver}/modules/module-combine-sink.so
%{_libdir}/pulse-%{drvver}/modules/module-console-kit.so
%{_libdir}/pulse-%{drvver}/modules/module-dbus-protocol.so
%{_libdir}/pulse-%{drvver}/modules/module-default-device-restore.so
%{_libdir}/pulse-%{drvver}/modules/module-detect.so
%{_libdir}/pulse-%{drvver}/modules/module-device-manager.so
%{_libdir}/pulse-%{drvver}/modules/module-device-restore.so
%{_libdir}/pulse-%{drvver}/modules/module-echo-cancel.so
%{_libdir}/pulse-%{drvver}/modules/module-equalizer-sink.so
%{_libdir}/pulse-%{drvver}/modules/module-filter-apply.so
%{_libdir}/pulse-%{drvver}/modules/module-filter-heuristics.so
%{_libdir}/pulse-%{drvver}/modules/module-http-protocol-tcp.so
%{_libdir}/pulse-%{drvver}/modules/module-http-protocol-unix.so
%{_libdir}/pulse-%{drvver}/modules/module-intended-roles.so
%{_libdir}/pulse-%{drvver}/modules/module-ladspa-sink.so
%{_libdir}/pulse-%{drvver}/modules/module-loopback.so
%{_libdir}/pulse-%{drvver}/modules/module-match.so
%{_libdir}/pulse-%{drvver}/modules/module-mmkbd-evdev.so
%{_libdir}/pulse-%{drvver}/modules/module-native-protocol-fd.so
%{_libdir}/pulse-%{drvver}/modules/module-native-protocol-tcp.so
%{_libdir}/pulse-%{drvver}/modules/module-native-protocol-unix.so
%{_libdir}/pulse-%{drvver}/modules/module-null-sink.so
%{_libdir}/pulse-%{drvver}/modules/module-null-source.so
%{_libdir}/pulse-%{drvver}/modules/module-oss.so
%{_libdir}/pulse-%{drvver}/modules/module-pipe-sink.so
%{_libdir}/pulse-%{drvver}/modules/module-pipe-source.so
%{_libdir}/pulse-%{drvver}/modules/module-position-event-sounds.so
%{_libdir}/pulse-%{drvver}/modules/module-remap-sink.so
%{_libdir}/pulse-%{drvver}/modules/module-rescue-streams.so
%{_libdir}/pulse-%{drvver}/modules/module-role-cork.so
%{_libdir}/pulse-%{drvver}/modules/module-rtp-recv.so
%{_libdir}/pulse-%{drvver}/modules/module-rtp-send.so
%{_libdir}/pulse-%{drvver}/modules/module-rygel-media-server.so
%{_libdir}/pulse-%{drvver}/modules/module-simple-protocol-tcp.so
%{_libdir}/pulse-%{drvver}/modules/module-simple-protocol-unix.so
%{_libdir}/pulse-%{drvver}/modules/module-sine.so
%{_libdir}/pulse-%{drvver}/modules/module-sine-source.so
%{_libdir}/pulse-%{drvver}/modules/module-stream-restore.so
%{_libdir}/pulse-%{drvver}/modules/module-suspend-on-idle.so
%{_libdir}/pulse-%{drvver}/modules/module-switch-on-connect.so
%{_libdir}/pulse-%{drvver}/modules/module-switch-on-port-available.so
%{_libdir}/pulse-%{drvver}/modules/module-systemd-login.so
%{_libdir}/pulse-%{drvver}/modules/module-tunnel-sink.so
%{_libdir}/pulse-%{drvver}/modules/module-tunnel-sink-new.so
%{_libdir}/pulse-%{drvver}/modules/module-tunnel-source.so
%{_libdir}/pulse-%{drvver}/modules/module-tunnel-source-new.so
%{_libdir}/pulse-%{drvver}/modules/module-udev-detect.so
%{_libdir}/pulse-%{drvver}/modules/module-virtual-sink.so
%{_libdir}/pulse-%{drvver}/modules/module-virtual-source.so
%{_libdir}/pulse-%{drvver}/modules/module-virtual-surround-sink.so
%{_libdir}/pulse-%{drvver}/modules/module-volume-restore.so
%{_libdir}/pulse-%{drvver}/modules/module-remap-source.so
%{_libdir}/pulse-%{drvver}/modules/module-role-ducking.so
%{_udevrulesdir}/90-pulseaudio.rules
%{_mandir}/man1/pulseaudio.1*
%{_mandir}/man5/default.pa.5*
%{_mandir}/man5/pulse-client.conf.5*
%{_mandir}/man5/pulse-daemon.conf.5*
%{_mandir}/man5/pulse-cli-syntax.5*
%dir %{_sysconfdir}/pulse/
%dir %{_sysconfdir}/pulse/daemon.conf.d
%dir %{_sysconfdir}/pulse/default.pa.d
%dir %{_sysconfdir}/pulse/system.pa.d
%config %{_sysconfdir}/pulse/client.conf.d/50-system.conf
%config(noreplace) %{_sysconfdir}/pulse/daemon.conf.d/60-disable_flat_volumes.conf
%config(noreplace) %{_sysconfdir}/pulse/daemon.conf
%config(noreplace) %{_sysconfdir}/pulse/default.pa
%config(noreplace) %{_sysconfdir}/pulse/system.pa
%config(noreplace) %{_sysconfdir}/dbus-1/system.d/pulseaudio-system.conf
# init
%dir %{_userunitdir}
%{_userunitdir}/%{name}.service
%{_userunitdir}/%{name}.socket
%{_prefix}/lib/tmpfiles.d/pulseaudio.conf
%ghost %dir %{_localstatedir}/lib/pulseaudio

# xwayland integration
%{_userunitdir}/pulseaudio-x11.service

%files setup
%{_bindir}/setup-pulseaudio
%{_fillupdir}/sysconfig.sound-pulseaudio
# created by setup-pulseaudio script
%ghost %{_sysconfdir}/profile.d/pulseaudio.sh
%ghost %{_sysconfdir}/profile.d/pulseaudio.csh

%files gdm-hooks
%attr(0750, gdm, gdm) %ghost %dir %{_localstatedir}/lib/gdm
%attr(0700, gdm, gdm) %ghost %dir %{_localstatedir}/lib/gdm/.pulse
%attr(0600, gdm, gdm) %ghost %{_localstatedir}/lib/gdm/.pulse/default.pa
%dir %{_prefix}/share/factory/var
%dir %{_prefix}/share/factory/var/lib
%dir %{_prefix}/share/factory/var/lib/gdm
%dir %{_prefix}/share/factory/var/lib/gdm/.pulse
%{_prefix}/share/factory/var/lib/gdm/.pulse/default.pa
%{_prefix}/lib/tmpfiles.d/pulseaudio-gdm-hooks.conf

%files -n libpulse%{soname}
%license LICENSE GPL LGPL
%dir %{_sysconfdir}/pulse/
%dir %{_sysconfdir}/pulse/client.conf.d
%config(noreplace) %{_sysconfdir}/pulse/client.conf
%{_libdir}/libpulse.so.%{soname}
%{_libdir}/libpulse.so.%{soname}.*
%{_libdir}/libpulse-simple.so.*
%dir %{_libdir}/pulseaudio
%{_libdir}/pulseaudio/libpulsecommon-%{drvver}.so

%files -n libpulse-devel
%{_includedir}/pulse/
%{_libdir}/libpulse.so
%{_libdir}/libpulse-mainloop-glib.so
%{_libdir}/libpulse-simple.so
%{_libdir}/pkgconfig/libpulse*.pc
%dir %{_libdir}/cmake
%dir %{_libdir}/cmake/PulseAudio
%{_libdir}/cmake/PulseAudio/PulseAudio*.cmake
%{_datadir}/vala

%files -n libpulse-mainloop-glib%{soname}
%{_libdir}/libpulse-mainloop-glib.so.%{soname}
%{_libdir}/libpulse-mainloop-glib.so.%{soname}.*
%{_datadir}/glib-2.0/schemas/org.freedesktop.pulseaudio.gschema.xml

%files module-bluetooth
%dir %{_libdir}/pulse-%{drvver}
%dir %{_libdir}/pulse-%{drvver}/modules
%{_libdir}/pulse-%{drvver}/modules/module-bluetooth-policy.so
%{_libdir}/pulse-%{drvver}/modules/module-bluetooth-discover.so
%{_libdir}/pulse-%{drvver}/modules/libbluez5-util.so
%{_libdir}/pulse-%{drvver}/modules/module-bluez5-device.so
%{_libdir}/pulse-%{drvver}/modules/module-bluez5-discover.so

%files module-gsettings
%dir %{_libexecdir}/pulse
%dir %{_libdir}/pulse-%{drvver}
%dir %{_libdir}/pulse-%{drvver}/modules
%{_libdir}/pulse-%{drvver}/modules/module-gsettings.so
%{_libexecdir}/pulse/gsettings-helper
%{_datadir}/GConf/gsettings/pulseaudio.convert

%files module-lirc
%dir %{_libdir}/pulse-%{drvver}
%dir %{_libdir}/pulse-%{drvver}/modules
%{_libdir}/pulse-%{drvver}/modules/module-lirc.so

%files module-jack
%dir %{_libdir}/pulse-%{drvver}
%dir %{_libdir}/pulse-%{drvver}/modules
%{_libdir}/pulse-%{drvver}/modules/module-jack-sink.so
%{_libdir}/pulse-%{drvver}/modules/module-jack-source.so
%{_libdir}/pulse-%{drvver}/modules/module-jackdbus-detect.so

%files module-x11
%dir %{_libdir}/pulse-%{drvver}
%dir %{_libdir}/pulse-%{drvver}/modules
%{_sysconfdir}/xdg/autostart/pulseaudio.desktop
%{_bindir}/start-pulseaudio-x11
%{_libdir}/pulse-%{drvver}/modules/module-x11-bell.so
%{_libdir}/pulse-%{drvver}/modules/module-x11-cork-request.so
%{_libdir}/pulse-%{drvver}/modules/module-x11-publish.so
%{_libdir}/pulse-%{drvver}/modules/module-x11-xsmp.so
%{_mandir}/man1/start-pulseaudio-x11.1*

%files module-zeroconf
%dir %{_libdir}/pulse-%{drvver}
%dir %{_libdir}/pulse-%{drvver}/modules
%{_libdir}/pulse-%{drvver}/modules/libavahi-wrap.so
%{_libdir}/pulse-%{drvver}/modules/libraop.so
%{_libdir}/pulse-%{drvver}/modules/module-raop-discover.so
%{_libdir}/pulse-%{drvver}/modules/module-raop-sink.so
%{_libdir}/pulse-%{drvver}/modules/module-zeroconf-discover.so
%{_libdir}/pulse-%{drvver}/modules/module-zeroconf-publish.so

%files utils
%{_bindir}/pa-info
%{_bindir}/pacat
%{_bindir}/pacmd
%{_bindir}/pactl
%{_bindir}/paplay
%{_bindir}/parec
%{_bindir}/pamon
%{_bindir}/parecord
%{_bindir}/pax11publish
%{_bindir}/padsp
%{_bindir}/pasuspender
%dir %{_libdir}/pulseaudio
%{_libdir}/pulseaudio/libpulsedsp.so
%{_mandir}/man1/pacat.1*
%{_mandir}/man1/pacmd.1*
%{_mandir}/man1/pactl.1*
%{_mandir}/man1/paplay.1*
%{_mandir}/man1/pasuspender.1*
%{_mandir}/man1/padsp.1*
%{_mandir}/man1/pax11publish.1*
%{_mandir}/man1/pamon.1%{ext_man}
%{_mandir}/man1/parec.1%{ext_man}
%{_mandir}/man1/parecord.1%{ext_man}

%files lang -f %{name}.lang

%files system-wide
%{_sbindir}/rc%{name}
%{_unitdir}/%{name}.service

%files bash-completion
%dir %{_datadir}/bash-completion
%dir %{_datadir}/bash-completion/completions
%{_bashcompletionsdir}/pulseaudio
%{_bashcompletionsdir}/pacat
%{_bashcompletionsdir}/pacmd
%{_bashcompletionsdir}/pactl
%{_bashcompletionsdir}/padsp
%{_bashcompletionsdir}/paplay
%{_bashcompletionsdir}/parec
%{_bashcompletionsdir}/parecord
%{_bashcompletionsdir}/pasuspender

%files zsh-completion
%dir %{_datarootdir}/zsh
%dir %{_datarootdir}/zsh/site-functions/
%{_datarootdir}/zsh/site-functions/_pulseaudio

%files -n system-user-pulse
%{_sysusersdir}/system-user-pulse.conf

%changelog
* Fri Jan 14 2022 tiwai@suse.de
- Workaround for spurious errors in dump-modules command
  (bsc#1194379):
  pulseaudio-dump-module-Ignore-invalid-module-init-tools.patch
* Wed Jan  5 2022 dimstar@opensuse.org
- Fix parameters passed to meson:
  * access-group, => access_group, system-group => system_group,
    and system-user => system_user for them to actually have an
    effect.
* Thu Dec 30 2021 tiwai@suse.de
- Fix a typo in padsp LD_PRELOAD setup (bsc#1194074)
* Tue Nov 23 2021 tiwai@suse.de
- Improving the handling with pipewire (bsc#1188516):
  * Split the setup script to a sub-package pulseaudio-setup to be
    shared with pipewire-pulseaudio package
  * Modified setup script to adapt pipewire-pulse
* Wed Nov 17 2021 gmbr3@opensuse.org
- Revert last change and BuildIgnore user(pulse) instead.
* Tue Nov 16 2021 tiwai@suse.de
- Use system-user-pulse instead of user(pulse) for PreReq;
  otherwise a new project can't resolve
* Fri Oct  8 2021 jengelh@inai.de
- Make system-user-pulse noarch
* Mon Oct  4 2021 gmbr3@opensuse.org
- Split sysusers.d file to separate package as needed by brltty
  (bsc#1191465)
* Thu Sep 16 2021 sbrabec@suse.com
- Remove obsolete translation-update-upstream support
  (jsc#SLE-21105).
- Require perl-XML-Parser explicitly, it's needed by build.
* Wed Aug 25 2021 tiwai@suse.de
- Drop SDL_AUDIODRIVER override, as SDL already prefers PA as
  default; this also fixes the recent breakage with SDL2 (bsc#1189778)
* Tue Aug  3 2021 oholecek@suse.com
- Update to PulseAudio 15
  - drop esound compat support
  - drop gconf support
  - convert to mason build system
  - disable doxygen doc generation
  - droped patches:
    drop bluetooth patches integrated in release:
    0001-bluetooth-use-consistent-profile-names.patch
    0002-bluetooth-separate-HSP-and-HFP.patch
    0003-bluetooth-add-correct-HFP-rfcomm-negotiation.patch
    0004-bluetooth-make-native-the-default-backend.patch
    0005-bluetooth-enable-module-bluez5-discover-argument-ena.patch
    0006-bluetooth-fix-headset-auto-ofono-handover.patch
    0007-bluetooth-prefer-headset-HFP-HF-connection-with-nati.patch
    0008-bluetooth-complete-bluetooth-profile-separation.patch
    0009-bluetooth-use-device-flag-to-prevent-assertion-failu.patch
    0010-bluetooth-rename-enable_hs_role-to-enable_shared_pro.patch
    0011-bluetooth-clean-up-rfcomm_write-usage.patch
    drop parecord patches integrated in release
    parecord-fix-Failed-to-open-audio-file-for-FLAC-and-.patch
    parecord-really-fix-recording-OGG.patch
  - refresh disabled-start.diff patch
  - new features:
  * Support for LDAC and AptX bluetooth codecs, plus "SBC XQ" (SBC with higher-quality parameters)
  * Support for HFP bluetooth profiles
  * Support for Bluetooth A2DP AVRCP Absolute Volume
  * ALSA path configuration files can now be placed in user home directory
  * module-virtual-surround-sink rewritten
  * More options for module-jackdbus-detect
  * Improved hardware support
  * SteelSeries Arctis 9
  * HP Thunderbolt Dock 120W G2
  * Behringer U-Phoria UMC22
  * OnePlus Type-C Bullets
  * Sennheiser GSX 1000/1200 PRO
  * New udev variable: PULSE_MODARGS
  * max_latency_msec argument added to module-null-source
  * module-filter-apply can take filter parameters from device properties
  * module-match can now be loaded multiple times
  * Improvements to FreeBSD support
  * Windows support added to Meson
  * Additional commands for pactl
  * Card profiles can be set to sticky
  * The startup script can now read additional configuration from the /etc/pulse/default.pa.d/ directory
  * * Notes for application developers
  * New API for sending messages from clients to PulseAudio objects
  * New mechanism for applications to disable shared memory on their connection to PulseAudio
  ( https://www.freedesktop.org/wiki/Software/PulseAudio/Notes/15.0/ )
* Sun Jul 18 2021 gmbr3@opensuse.org
- Remove unneeded shadow dependency, no longer required due to
  systemd-sysusers
* Sat Jun 26 2021 gmbr3@opensuse.org
- Change to using systemd-sysusers
- Remove old SUSE RPM constructs
* Mon Apr 19 2021 mwilck@suse.com
- Really fix recording OGG with parecord (bsc#1183546)
  parecord-really-fix-recording-OGG.patch
* Tue Mar 16 2021 dmueller@suse.com
- move license to licensedir
* Mon Mar 15 2021 mwilck@suse.com
- Fix "Failed to open audio file" for FLAC and OGG (bsc#1183546)
  parecord-fix-Failed-to-open-audio-file-for-FLAC-and-.patch
* Mon Mar  1 2021 tiwai@suse.de
- Upstream fixes for supporting HFP in native backend (bsc#1167940):
  0001-bluetooth-use-consistent-profile-names.patch
  0002-bluetooth-separate-HSP-and-HFP.patch
  0003-bluetooth-add-correct-HFP-rfcomm-negotiation.patch
  0004-bluetooth-make-native-the-default-backend.patch
  0005-bluetooth-enable-module-bluez5-discover-argument-ena.patch
  0006-bluetooth-fix-headset-auto-ofono-handover.patch
  0007-bluetooth-prefer-headset-HFP-HF-connection-with-nati.patch
  0008-bluetooth-complete-bluetooth-profile-separation.patch
  0009-bluetooth-use-device-flag-to-prevent-assertion-failu.patch
  0010-bluetooth-rename-enable_hs_role-to-enable_shared_pro.patch
  0011-bluetooth-clean-up-rfcomm_write-usage.patch
* Thu Feb 25 2021 alarrosa@suse.com
- Let pulseaudio-utils require any pulseaudio-daemon provider
  so parecord and the other utils can be used with other
  pulseaudio implementations
* Thu Feb 25 2021 alarrosa@suse.com
- Provide pulseaudio-daemon capability so pipewire-pulseaudio can
  also provide that capability instead of providing 'pulseaudio'
  itself which makes it difficult to recommend the pulseaudio
  package (boo#1182730).
* Fri Jan 29 2021 tiwai@suse.de
- Drop the bad patch: pulseaudio-wrong-memset.patch
  the patch has been wrongly refreshed, mutated into a harmful form.
  The original bug has been already fixed in the upstream commit 764eabd10.
* Thu Jan 28 2021 dimstar@opensuse.org
- Supplement pulseaudio-bash-completion against bash-completion,
  not bash.
* Tue Jan 26 2021 guillaume.gardet@opensuse.org
- Disable LTO on armv7 as it breaks the build
* Sun Jan 24 2021 dmueller@suse.com
- udpate to 14.2:
  * Support upto 8 mixer channels on ALSA devices
  * Handle ALSA jacks with the same name but different index values
  * Switch to plugged-in headset when mic availability is unknown
  * Fix a potential segfault in the Bluetooth oFono HFP backend
  * Fix a problem with module-ladspa-sink when avoid-resampling=true
  * Update to the NEWS file for 14.0 (and 14.1)
  * Fix database names containing canonical host for meson builds
* Wed Jan 13 2021 tiwai@suse.de
- Drop the outdated module-rescue-stream from gdm default config
  (bsc#1180869)
* Thu Jan  7 2021 tiwai@suse.de
- Fix copyright in the spec file for SLE submission
* Tue Dec 15 2020 mliska@suse.cz
- Enable LTO (boo#1133278) as it works now.
* Wed Nov 25 2020 tiwai@suse.de
- Update to pulseaudio 14.0:
  see details in:
    https://www.freedesktop.org/wiki/Software/PulseAudio/Notes/14.0/
- Build with --enable-stream-restore-clear-old-devices:
  This is a bit destructive option, it will clear the old PA routing
  once when upgraded prior to 14.0, but it's required for GNOME
  (see the release notes above).  It should be a one-off action,
  and hopefully wouldn't bother too much.
- Drop obsoleted patches:
  0001-alsa-mixer-path-test-Hide-unused-functions-when-buil.patch
  0002-alsa-mixer-recognize-the-Speaker-Jack-control.patch
  0003-alsa-mixer-add-support-for-SteelSeries-Arctis-Pro-20.patch
  0004-alsa-mixer-Add-support-for-SteelSeries-Arctis-5-2019.patch
  0005-alsa-mixer-add-support-for-LucidSound-LS31-and-creat.patch
  0006-alsa-ucm-use-ucm2-name-for-the-direct-card-index-ope.patch
  0007-alsa-ucm-add-mixer-IDs-to-ucm_items.patch
  0008-alsa-mixer-handle-the-index-for-ALSA-mixer-element-i.patch
  0009-alsa-mixer-improve-alsa_id_decode-function.patch
  0010-alsa-ucm-Support-Playback-CaptureVolume.patch
  0011-alsa-ucm-Fix-volume-control-based-on-review.patch
  0012-alsa-ucm-use-the-correct-mixer-identifiers-as-first.patch
  0013-alsa-ucm-add-support-for-master-volume.patch
  0014-alsa-ucm-split-correctly-JackHWMute-device-names.patch
  0015-alsa-ucm-fix-parsing-for-JackControl.patch
  0016-alsa-ucm-add-comments-to-ucm_get_mixer_id.patch
  0017-alsa-ucm-validate-access-to-PA_DEVICE_PORT_DATA.patch
  0018-alsa-Skip-resume-PCM-if-hardware-doesn-t-support-it.patch
  0019-alsa-ucm-parse-correctly-the-device-values.patch
  0020-alsa-ucm-do-not-try-to-use-UCM-device-name-as-jack-n.patch
  0021-alsa-util-do-not-try-to-guess-the-mixer-name-from-th.patch
  0022-alsa-ucm-add-control-and-mixer-device-items.patch
  0023-alsa-ucm-get-the-mixer-names-from-ucm-don-t-guess.patch
  0024-alsa-ucm-use-the-proper-mixer-name-for-ucm-pcm-sink-.patch
  0025-alsa-mixer-handle-interface-type-CARD-PCM-for-mixer-.patch
  0026-alsa-mixer-Add-the-ability-to-pass-the-intended-role.patch
  0027-alsa-mixer-Set-the-intended-role-of-Steelseries-Arct.patch
  0028-alsa-rewrite-mixer-open-close-cache-mixer-accesses-i.patch
  0029-alsa-ucm-add-support-for-HDMI-ELD.patch
  0030-alsa-mixer-do-the-quick-card-number-lookup-to-save-m.patch
  0031-alsa-mixer-improve-check-for-the-empty-path-set-for-.patch
  0032-alsa-ucm-allow-to-set-profile-priority-from-UCM-valu.patch
  0033-alsa-Document-that-mixer-elements-can-be-identified-.patch
  0034-alsa-ucm-correct-the-channel-default-logic-stereo.patch
  0035-alsa-ucm-do-not-assign-JackHWMute-when-JackControl-i.patch
  0036-ucm-Don-t-log-errors-during-normal-operation.patch
  0037-alsa-handle-unavailbale-HW-volume-in-UCM.patch
  0038-alsa-ucm-use-the-right-profile-name.patch
  0039-ucm-fix-the-port-ucm-device-activation-on-boot.patch
  0040-alsa-sink-source-fix-the-mixer-initialization.patch
* Mon Jun 22 2020 callumjfarmer13@gmail.com
- Fixes for %%_libexecdir changing to /usr/libexec
* Sun Jun  7 2020 meissner@suse.com
- for libpulse-devel-32bit, require libpulse0-32bit + libpulse-mainloop-glib0-32bit
  to help wine development (bsc#1172301)
* Wed May 13 2020 tiwai@suse.de
- Backport upstream fixes for ALSA UCM profile handling
  (boo#1171492):
  0033-alsa-Document-that-mixer-elements-can-be-identified-.patch
  0034-alsa-ucm-correct-the-channel-default-logic-stereo.patch
  0035-alsa-ucm-do-not-assign-JackHWMute-when-JackControl-i.patch
  0036-ucm-Don-t-log-errors-during-normal-operation.patch
  0037-alsa-handle-unavailbale-HW-volume-in-UCM.patch
  0038-alsa-ucm-use-the-right-profile-name.patch
  0039-ucm-fix-the-port-ucm-device-activation-on-boot.patch
  0040-alsa-sink-source-fix-the-mixer-initialization.patch
* Thu Apr  2 2020 tiwai@suse.de
- Control systemd user socket activation in setup-pulseaudio script
  too (boo#1168393)
* Wed Feb 12 2020 tiwai@suse.de
- Backport upstream fixes / enhancements about alsa modules:
  mainly for UCM support (boo#1160914):
  0001-alsa-mixer-path-test-Hide-unused-functions-when-buil.patch
  0002-alsa-mixer-recognize-the-Speaker-Jack-control.patch
  0003-alsa-mixer-add-support-for-SteelSeries-Arctis-Pro-20.patch
  0004-alsa-mixer-Add-support-for-SteelSeries-Arctis-5-2019.patch
  0005-alsa-mixer-add-support-for-LucidSound-LS31-and-creat.patch
  0006-alsa-ucm-use-ucm2-name-for-the-direct-card-index-ope.patch
  0007-alsa-ucm-add-mixer-IDs-to-ucm_items.patch
  0008-alsa-mixer-handle-the-index-for-ALSA-mixer-element-i.patch
  0009-alsa-mixer-improve-alsa_id_decode-function.patch
  0010-alsa-ucm-Support-Playback-CaptureVolume.patch
  0011-alsa-ucm-Fix-volume-control-based-on-review.patch
  0012-alsa-ucm-use-the-correct-mixer-identifiers-as-first.patch
  0013-alsa-ucm-add-support-for-master-volume.patch
  0014-alsa-ucm-split-correctly-JackHWMute-device-names.patch
  0015-alsa-ucm-fix-parsing-for-JackControl.patch
  0016-alsa-ucm-add-comments-to-ucm_get_mixer_id.patch
  0017-alsa-ucm-validate-access-to-PA_DEVICE_PORT_DATA.patch
  0018-alsa-Skip-resume-PCM-if-hardware-doesn-t-support-it.patch
  0019-alsa-ucm-parse-correctly-the-device-values.patch
  0020-alsa-ucm-do-not-try-to-use-UCM-device-name-as-jack-n.patch
  0021-alsa-util-do-not-try-to-guess-the-mixer-name-from-th.patch
  0022-alsa-ucm-add-control-and-mixer-device-items.patch
  0023-alsa-ucm-get-the-mixer-names-from-ucm-don-t-guess.patch
  0024-alsa-ucm-use-the-proper-mixer-name-for-ucm-pcm-sink-.patch
  0025-alsa-mixer-handle-interface-type-CARD-PCM-for-mixer-.patch
  0026-alsa-mixer-Add-the-ability-to-pass-the-intended-role.patch
  0027-alsa-mixer-Set-the-intended-role-of-Steelseries-Arct.patch
  0028-alsa-rewrite-mixer-open-close-cache-mixer-accesses-i.patch
  0029-alsa-ucm-add-support-for-HDMI-ELD.patch
  0030-alsa-mixer-do-the-quick-card-number-lookup-to-save-m.patch
  0031-alsa-mixer-improve-check-for-the-empty-path-set-for-.patch
  0032-alsa-ucm-allow-to-set-profile-priority-from-UCM-valu.patch
* Mon Feb  3 2020 bjorn.lie@gmail.com
- No longer recommend -lang: supplements are in use.
* Thu Dec 19 2019 dimstar@opensuse.org
- BuildRequire pkgconfig(libudev) instead of libudev-devel: allow
  OBS to work with the -mini flavors. There is no need to be
  scheduled behind the full systemd.
* Mon Oct  7 2019 fcrozat@suse.com
- Update pulseaudio-gdm-hooks.tmpfiles to use the same ownership
  and permissions as in specfile for pulseaudio files.
- Update default.pa-for-gdm to not load bluetooth support in
  pulseaudio gdm instance. This ensure headset are not stolen by
  gdm instance instead of user instance. Idea from ArchLinux.
- Update pulseaudio-old-systemd-workaround.patch to disable
  LockPersonality also on Leap 15.x.
* Sun Sep 22 2019 bjorn.lie@gmail.com
- Pass --disable-running-from-build-tree to configure for improving
  build reproducibility.
- Add pulseaudio-rpmlintrc: Filter out false positive warnings
  about hidden files in pulseaudio-gdm-hooks.
* Mon Sep 16 2019 bjorn.lie@gmail.com
- Update to version 13.0:
  * Added support for Dolby TrueHD and DTS-HD Master Audio
  * Improved initial card profile selection for ALSA cards
  * Bluetooth card profile choices aren't persistent any more by
    default.
  * Added support for SteelSeries Arctis 5 USB headset.
  * New "max_latency_msec" module argument for module-loopback.
  * New "stream_name" module argument for module-rtp-send.
  * Fixed S/PDIF for CMEDIA USB2.0 High-Speed True HD Audio.
  * Use source sample spec and channel map by default in
    module-loopback.
  * New "avoid_resampling" module argument for module-udev-detect
    and module-alsa-card.
  * "avoid_resampling" also tries to avoid format conversion if the
    ALSA device supports it.
  * New function to enable realtime scheduling for client threads.
  * Removed BlueZ 4 support.
  * Dropped intltool.
  * Introduction of the Meson build system.
  * Const-ification of parameters across headers.
  * Minor bug-fixes, bindings updates.
  * Updated translations.
- Update drvver to 13.0.
* Sun Sep  8 2019 bjorn.lie@gmail.com
- Use make_build macros.
* Tue Aug 27 2019 tiwai@suse.de
- Workaround for old systemd on Leap 15.x, as the recent hardening
  relies on the new systemd:
  pulseaudio-old-systemd-workaround.patch
* Tue Aug  6 2019 oholecek@suse.com
- Update to 13 RC2 (12.99.2)
  * Added support for Dolby TrueHD and DTS-HD Master Audio
  * Improved initial card profile selection for ALSA cards
  * Bluetooth card profile choices aren't persistent any more by default
  * Added support for SteelSeries Arctis 5 USB headset
  * New "max_latency_msec" module argument for module-loopback
  * New "stream_name" module argument for module-rtp-send
  * Fixed S/PDIF for CMEDIA USB2.0 High-Speed True HD Audio
  * Use source sample spec and channel map by default in module-loopback
  * New "avoid_resampling" module argument for module-udev-detect and module-alsa-card
  * New function to enable realtime scheduling for client threads
  * Removed BlueZ 4 support
  * Dropped intltool
  * Some initial work on a Meson build system
  * https://www.freedesktop.org/wiki/Software/PulseAudio/Notes/13.0/
- Removed patches already included in the source:
  pulseaudio-alsa.patch
  pa-set-exit-idle-time-to-0-when-we-detect-a-session.patch
* Thu Jul 11 2019 antoine.belvire@opensuse.org
- Remove SuSEfirewall2 service since SuSEfirewall2 has been
  replaced by firewalld (which already provides a service for
  pulseaudio).
- Remove some obsolete macros and conditionals.
* Tue Jun 11 2019 bjorn.lie@gmail.com
- Rebase qpaeq-shebang.patch to python3 instead of python, as we
  build pulseaudio with python3 support and not python2. Aka
  pulseaudio requires /usr/bin/python3 and not /usr/bin/python.
* Tue Jun 11 2019 dimstar@opensuse.org
- BuildRequire pkgconfig(systemd) instead of systemd: allow OBS to
  shortcut the build queues by allowing usage of systemd-mini
* Fri Apr 26 2019 mvetter@suse.com
- bsc#1130588: Require shadow instead of old pwdutils
* Wed Apr 24 2019 mliska@suse.cz
- Disable LTO (boo#1133278).
* Sun Apr 21 2019 tiwai@suse.de
- Fix the UCM module build due to the removal of alsa/* include
  path (bsc#1132880):
  updated pulseaudio-alsa.patch
* Wed Mar 27 2019 jengelh@inai.de
- Remove one redundant Requires: systemd, and add
  BuildRequires: systemd-rpm-macros.
* Tue Mar 26 2019 olaf@aepfle.de
- Use alsa API properly. Consumers are expected to use
  <alsa/asoundlib.h> instead of <asoundlib.h>.
  This is in preparation of an change to pkgconfig(alsa) to
  not pollute CFLAGS with -I/usr/include/alsa anymore (bsc#1130333)
  pulseaudio-alsa.patch
* Wed Jan 30 2019 alarrosa@suse.com
- Make /var/lib/gdm %%ghost again in pulseaudio-gdm-hooks so we don't
  create the directory when installing the package. gdm was just
  changed to create that directory as %%ghost too to keep both
  packages in sync.
- Add /var/lib/pulseaudio (which is already created by systemd-tmpfiles)
  as %%ghost so users can easily query who created the directory,
  it gets uninstalled on package removal and rpmlint doesn't complain
  about it.
* Tue Jan 15 2019 tiwai@suse.de
- Enable systemd user socket for activating PA (bsc#1083473)
- Disable auto-spawn along with the change above
* Sun Nov 18 2018 tiwai@suse.de
- Drop ghost from gdm hook dir to sync with gdm package itself
* Thu Nov 15 2018 tiwai@suse.de
- Fix setup-pulseaudio script to deal with the new alsa/conf.d
  setup that was introduced since alsa-lib 1.1.7 (bsc#1116153)
* Fri Oct 19 2018 alarrosa@suse.com
- Add a Supplements line to pulseaudio-gdm-hooks so it's selected
  for installation when gdm and pulseaudio are installed.
* Thu Oct 18 2018 alarrosa@suse.com
- Don't create files under /var on package installation but using
  systemd-tmpfiles to be friendly to transactional updates
  (bsc#1098063, fate#325524)
- Add pulseaudio.tmpfiles and pulseaudio-gdm-hooks.tmpfiles
* Mon Jul 16 2018 oholecek@suse.com
- Update to 12.2
  * Fixed broken configure script (building failed when gsettings
    was enabled)
- Update to 12.1
  * Fixed a crash when switching to the A2DP bluetooth profile
  * Fixed the plugin search path in module-ladspa-sink
  * Fixed file permissions for the pipes created by module-pipe-sink and
  module-pipe-source
- Remove patch 0001-Revert-ladspa-sink-fix-Windows-compilation.patch
* Thu Jun 21 2018 oholecek@suse.com
- Update to 12 (for complete changes see RC1 + following)
  * Better latency reporting (and hence better A/V sync) with the A2DP
    bluetooth profile
  * Fixed a crash or high CPU use problem with Intel HDMI LPE
  * module-pipe-sink can now use an existing pipe
  * Fixed Native Instruments Traktor Audio 6 detection
  * Updates for the Vala bindings
  * Compatibility with glibc 2.27
  * The esdcompat tool isn't any more installed if esound support is
    disabled
* Tue Jun 19 2018 tiwai@suse.de
- Revert the gconf module removal; plasma5-pa still requires it
  (while paprefs git version moved to gsettings) (bsc#1092871)
* Thu Jun 14 2018 tiwai@suse.de
- Fix LADSPA sink regression: revert the affecting commit
  (bsc#1097170):
  0001-Revert-ladspa-sink-fix-Windows-compilation.patch
* Wed Jun  6 2018 bjorn.lie@gmail.com
- Drop pkgconfig(gconf-2.0) BuildRequires: No longer mandatory,
  following this, replace --enable-gconf configure call with
  - -disable-gconf and add explicit pkgconfig(gio-2.0)
  BuildRequires.
- Following the above, drop pulseaudio-module-gconf sub-package,
  and obsolete it from pulseaudio-module-gsettings.
* Tue May 15 2018 oholecek@suse.com
- Update to 12 RC1 (11.99.1)
  * Much more accurate latency reporting for AirPlay devices
  * module-switch-on-connect now ignores virtual devices
  * When using passthrough for compressed audio, set the "non-audio" bit
  * Prioritize HDMI output over S/PDIF output
  * HSP support for more bluetooth headsets
  * Choose the A2DP bluetooth profile by default instead of HSP
  * New "sink_input_properties" module argument for module-ladspa-sink
  * New "use_system_clock_for_timing" module argument for module-pipe-sink
  * Steelseries Arctis 7 USB headset stereo output support
  * Dell Thunderbolt Dock TB16 speaker jack support
  * Fixed digital input support for some USB sound cards
  * Ability to disable input or output on macOS
  * New "dereverb" option for the Speex echo canceller
  * New module: module-always-source
  * State files not any more readable by all users in the system mode
  * module-augment-properties now uses XDG_DATA_DIRS to find .desktop files
  * The GConf dependency can now be avoided
  * qpaeq license changed from AGPL to LGPL
  * qpaeq ported to Qt 5
- Add subpackage module-gsettings (conflicts with module-gconf)
- Remove support for obsolete Bluez4
- Fix build phase running configure twice
- Removed patches:
  0001-alsa-fix-infinite-loop-with-Intel-HDMI-LPE.patch
  0002-alsa-mixer-add-hw_device_index-to-pa_alsa_mapping.patch
  0003-alsa-mixer-autodetect-the-HDMI-jack-PCM-device.patch
  0004-alsa-mixer-autodetect-the-ELD-device.patch
  pulseaudio-glibc2.27.patch
- Added patch:
  qpaeq-shebang.patch
* Thu Apr 19 2018 fcrozat@suse.com
- Add Supplements: packageand on zeroconf, lirc, bluetooth
  subpackages to have them selected for installation automatically
  instead of relying on patterns (bsc#1087207).
* Tue Mar  6 2018 tiwai@suse.de
- Fix the wrongly suspended sinks due to the previous patch
  (bsc#1084047):
  refreshed 0001-alsa-fix-infinite-loop-with-Intel-HDMI-LPE.patch
* Thu Mar  1 2018 tiwai@suse.de
- Fix the crash with Intel LPE HDMI audio (bsc#1083195):
  0001-alsa-fix-infinite-loop-with-Intel-HDMI-LPE.patch
  0002-alsa-mixer-add-hw_device_index-to-pa_alsa_mapping.patch
  0003-alsa-mixer-autodetect-the-HDMI-jack-PCM-device.patch
  0004-alsa-mixer-autodetect-the-ELD-device.patch
* Wed Feb 28 2018 tiwai@suse.de
- Abort PA process at session exit properly (bsc#1052437):
  pa-set-exit-idle-time-to-0-when-we-detect-a-session.patch
* Thu Feb 15 2018 dimstar@opensuse.org
- Add pulseaudio-glibc2.27.patch: Fix build with glibc 2.27
  (boo#1081023, fdo#104733).
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Tue Sep 19 2017 oholecek@suse.com
- Update to 11.1
  * Fix a crash in filter modules related to flat volumes and volume
  sharing
  * Fix a crash when the bluetooth adapter reports weird MTU size
  * Disable bluetooth MTU autodetection by default
  * Add mixer handling back for hardware that doesn't have any alsa-lib
    configuration
  * Prioritize USB devices over built-in sound cards (11.0 was supposed
    to have this feature, but the implementation turned out to be
    incomplete)
* Tue Sep  5 2017 oholecek@suse.com
- Update to 11 (11.0)
  * The default sink and source configuration is remembered better
  * https://www.freedesktop.org/wiki/Software/PulseAudio/Notes/11.0/
* Fri Jul 28 2017 oholecek@suse.com
- Fix Requires(post) and Requires(pre) mixup
* Tue Jul 25 2017 oholecek@suse.com
- Update to 11 RC1 (10.99.1)
  * Support for newer AirPlay hardware
  * USB and bluetooth devices preferred over internal sound cards
  * Bluetooth HSP headset role implemented
  * Bluetooth HFP audio gateway role implemented (requires oFono)
  * Bluetooth HSP audio gateway and HFP hands-free unit roles can
    be enabled simultaneously
  * Upmixing can now be disabled without bad side effects
  * Avoid having unavailable sinks or sources as the default
  * Option to avoid resampling more often
  * Option to automatically switch bluetooth profile to HSP more often
  * Better latency control in module-loopback
  * Changed module argument names in module-ladspa-sink and
    module-virtual-surround-sink
  * Fixed input device handling in module-waveout
  * Improved bluetooth MTU configuration (warning! this causes some
    hardware to not work any more, see the details below for how to fix it)
  * Applications can request LADSPA or virtual surround filtering for
    their streams
  * Support for 32-bit applications on 64-bit systems in padsp
- add --with-pulsedsp-location='/usr/\\$$LIB/pulseaudio' to enable
  upstream padsp multiarch fix
- remove patch4 padsp-biarch.patch, fixed upstream
- remove patch5 pulseaudio-vala-0.36.patch, fixed upstream
* Tue Mar 14 2017 kukuk@suse.de
- Prerequire group audio
* Mon Mar 13 2017 dimstar@opensuse.org
- Add pulseaudio-vala-0.36.patch: Introduce compatibility with
  vala 0.36.
* Thu Jan 19 2017 oholecek@suse.com
- Update to 10.0
  * Fixed hotplugging support for USB surround sound cards
  * Clarified qpaeq license
  * https://www.freedesktop.org/wiki/Software/PulseAudio/Notes/10.0/
* Wed Jan  4 2017 oholecek@suse.com
- Update to 10 RC1 (9.99.1)
  * Automatically switch Bluetooth profile when using VoIP applications
  * New module for prioritizing passthrough streams (module-allow-passthrough)
  * Improvements to module-loopback
  * Separate volumes for Bluetooth A2DP and HSP profiles
  * memfd-based shared memory mechanism enabled by default
  * Removed module-xenpv-sink
  * Dropped dependency to json-c
  * When using systemd to start PulseAudio, pulseaudio.socket is started first
  * Compatibility with OpenSSL 1.1.0
- Removed BuildRequires pkgconfig(json)
* Sun Sep  4 2016 zaitor@opensuse.org
- Stop passing --disable-bluez5-ofono-headset when using bluez5.
* Wed Jun 22 2016 oholecek@suse.com
- Update to 9.0
  * Automatic routing improvements
  * Beamforming and various other new features in the WebRTC echo
  canceller
  * Various improvements in module-role-cork and module-role-ducking
  * LFE remixing disabled by default
  * memfd-backed shared memory transport
  * Support for sample rates up to 384 kHz
  * webrtc-audio-processing dependency minimum version bumped to 0.2
  * Changed the C standard from C99 to C11.
- Updated depencency webrtc-audio-processing to 0.3
* Sun May 29 2016 oholecek@suse.com
- Update to 9.0 RC2 (8.99.2)
* Fri May 27 2016 oholecek@suse.com
- Update to 9.0 RC1 (8.99.1)
  + memfd support (off by default)
  + refinements to automatic switching to HDMI outputs
  + improvements to our echo canceller (including the addition of
    beamforming)
  + lots of other changes
- Updated dependency webrtc-audio-processing >= 0.2
- Do not mark shell completion includes as configs (solves some
  rpmlint warnings)
* Thu Apr 14 2016 tiwai@suse.de
- Use /etc/pulse/client.conf.d/50-system.conf as a system setup by
  setup-pulseaudio script instead of modifying the global config.
* Mon Apr  4 2016 tiwai@suse.de
- Move libpulsedsp.so into pulseaudio-utils subpackage and add it
  to baselibs.conf so that 32bit compat lib is built (boo#968568);
  also recommends is added in libpulse0-32bit for easy installation
- Fix padsp script to support bi-arch libs (boo#968568) with
  padsp-biarch.patch
- Call bootstrap.sh for rebuilding properly with patches
- Drop the obsoleted disable-srbchannel.patch, which has been fixed
  in upstream already
* Mon Mar 21 2016 lmuelle@suse.com
- Add pulse-%%{drvver} and modules subdirectories to any module package;
  (boo#971960).
* Wed Feb 24 2016 hguo@suse.com
- Disable flat-volumes by default with config disable_flat_volumes.conf
  Remedy for fate#310668.
* Fri Jan 22 2016 oholecek@suse.com
- Update to 8.0
  + Automatic routing more likely to change profile
  + OS X and NetBSD support improvements
  + Systemd journal logging for clients
  + New LFE balance programming interface
  + Module-dbus-protocol improvements
  + More flexible configuration file handling
  + pulsecore-8.0.so moved to a private directory
  + New script for measuring memory consumption
  + Various bug fixes and small improvements
  + https://wiki.freedesktop.org/www/Software/PulseAudio/Notes/8.0/
* Tue Jan 12 2016 oholecek@suse.com
- Update to 8.0 RC2 (7.99.2)
* Sun Jan  3 2016 oholecek@suse.com
- Update to 8.0 RC1 (7.99.1)
- remove 0004-module-alsa-card-Report-available-ports-before-unava.patch
* Mon Nov  2 2015 meissner@suse.com
- add libpulse-devel to baselibs.conf for use of 32bit biarch
  wine builds on x86_64
* Fri Oct 30 2015 oholecek@suse.com
- Update to 7.1
  + Fix a crasher when using srbchannel
  + Fix a build system typo that caused symlinks to turn up in /
  + Make Xonar cards work better
  + Other minor  bug fixes and improvements
- remove 0003-alsa-mixer-Add-Dock-Line-Out-jack-handling-to-analog.patch
- remove 0002-alsa-mixer-Recognize-Dock-Line-Out-jack.patch
- remove pstream-Fix-use-after-free-in-srb_callback.patch
* Tue Oct 20 2015 tiwai@suse.de
- Fix another alsa-mixer path for dock line out jack (boo#948979):
  0003-alsa-mixer-Add-Dock-Line-Out-jack-handling-to-analog.patch
- Fix the order of ports updates (boo#948979):
  0004-module-alsa-card-Report-available-ports-before-unava.patch
* Sat Oct 17 2015 tiwai@suse.de
- Upstream fix patch for srb channel corruption (boo#950487):
  pstream-Fix-use-after-free-in-srb_callback.patch
- Re-enable srbchannel again
* Thu Oct 15 2015 tiwai@suse.de
- Disable srbchannel again as a workaround for crashes on KDE
  (boo#950487):
  disable-srbchannel.patch
* Thu Sep 24 2015 oholecek@suse.com
- Update to 7.0
* Sun Sep 13 2015 oholecek@suse.com
- Update to 7.0 RC2 (6.99.2)
  + better support for Creative SoundBlaster Omni Surround 5.1 USB
  + coverity scan fixes
  + bug fixes
* Fri Aug 28 2015 oholecek@suse.com
- spec-cleaner run
* Fri Aug 28 2015 oholecek@suse.com
- Update to 7.0 RC1 (6.99.1)
  + LFE channel synthesis with low-pass filtering
  + New libsoxr based resamplers
  + Socket activation support for TCP
  + The "srbchannel" IPC mechanism enabled by default
  + More flexible jack detection support when using UCM
  + Exiting due to SIGTERM isn't considered a failure
- remove patch 0001-alsa-mixer-Make-line-out-path-unavailable-when-Front.patch
  (upstreamed)
* Fri Jul 31 2015 dimstar@opensuse.org
- Add pkgconfig(udev) BuildRequires: we explicitly expect udev.pc
  to be present to define _udevrulesdir.
* Thu Jul 23 2015 tiwai@suse.de
- Fix missing speex resampler due to the recent split of speexdsp
  (boo#939225)
* Tue Jun 16 2015 tiwai@suse.de
- Fix missing dock line-out jack detection (boo#934850):
  0001-alsa-mixer-Make-line-out-path-unavailable-when-Front.patch
  0002-alsa-mixer-Recognize-Dock-Line-Out-jack.patch
* Tue Apr  7 2015 sleep_walker@suse.cz
- create symlink providing extra-hdmi.conf (pointing to
  default.conf)
  it seems that some HW may get unitialized without this (check
  pulseaudio RC1 announce)
* Fri Feb 13 2015 oholecek@suse.com
- Uptade to 6.0
  + a few bug fixes since RC3
- disable oFono support, oFono package is not in distribution
  Note that oFono is needed only for Bluetooth HFP (Hands Free profile)
* Wed Jan 21 2015 oholecek@suse.com
- Update to 6.0 RC3 (5.99.3)
  + srbchannel has been disabled by default for 6.0
  (We still encourage testing of the srbchannel - do so by adding
    the "srbchannel=yes" to "load-module module-native-protocol-unix")
  + libsamplerate is deprecated
  + a problem causing wrong volume with orc 0.4.23 was worked around
  + translation updates (Swedish, Turkish)
  + a few other bug fixes
- remove patch pulseaudio-orc-0.4.23-volume-fix.patch
* Thu Jan  8 2015 tiwai@suse.de
- Fix broken volume setup with orc 0.4.23 (bsc#912260):
  pulseaudio-orc-0.4.23-volume-fix.patch
* Thu Jan  1 2015 meissner@suse.com
- build with PIE
* Fri Dec 19 2014 oholecek@suse.com
- Update to 6.0 RC2 (5.99.2)
  + Build system fixes for Debian/FreeBSD and mingw32
  + Some translation updates
  + Fixed A2DP profile not restored correctly
  + Configure fixes for bluez 5 native headset backend
  + Noise in the beginning of a recording (with srbchannel) fixed
  + Fixed a few memory safety issues
  + Added warnings for two unstable modules (module-equalizer-sink and
  module-dbus-protocol)
  + Enabled autospawn even when systemd socket activation is built in
* Wed Nov 26 2014 oholecek@suse.com
- remove obsoleted libsamplerate support
- make completion packages depend on utils subpackage
* Fri Nov 21 2014 oholecek@suse.com
- Update to 6.0 RC1 (5.99.1)
  + Bluez 5 HSP (headset profile) support, both with and without oFono
  + SystemD socket activation support
  + Better support for multichannel and 2.1 profiles
  + Protocol optimisations
  + Zsh shell completion support
  + Remap optimisations
  + Many minor improvements and bug fixes all across the place
- Remove patch pulseaudio-bnc881524-rtp.patch
- Update patch disabled-start.diff
- Bash&zsh completion split to separate subpackage
- Fix %%postun for system-wide mode
- json-c >= 0.11 is now required
  (break build on oS 13.1)
* Thu Nov 20 2014 tiwai@suse.de
- Revert yet another one due to still lost headphone handling
  (bnc#905418):
  alsa-mixer-recognize-Dock-headphone-jack.patch
* Mon Nov 17 2014 tiwai@suse.de
- Remove a patch causing more regressions, lost headphone handling
  on Thinkpads (bnc#905418):
  0002-alsa-mixer-Ignore-some-elements-in-the-analog-output.patch
* Wed Nov 12 2014 tiwai@suse.de
- Fix setup-pulseaudio script not to leave $ALSA_CONFIG_PATH when
  alsa-plugins-pulse isn't installed (bnc#905055)
* Wed Nov  5 2014 tiwai@suse.de
- Fix wrong mixer setup / jack detection issues (bnc#851362)
  0001-alsa-mixer-recognize-Dock-headphone-jack.patch
  0002-alsa-mixer-Ignore-some-elements-in-the-analog-output.patch
* Sat Oct 18 2014 crrodriguez@opensuse.org
- Replace xorg-x11-devel for the exact pkgconfig deps needed.
- Tell doxygen not to generate timestamped html docs.
* Tue Sep 16 2014 mpluskal@suse.com
- Add user pulse to audio group - see bnc#896846
* Fri Jul 18 2014 sreeves@suse.com
- Add pulseaudio-bnc881524-rtp.patch.  CVE-2014-3970
    Denial of service in module-rtp-recv
* Thu Mar 20 2014 crrodriguez@opensuse.org
-  build: do not depend on tcpd-devel which is unmaintained
- pulseaudio.service: Use the new journal log target.
* Mon Mar  3 2014 oholecek@suse.com
- Update to 5.0 final
  + BlueZ 5 support (A2DP only)
  + Reimplementation of the tunnel modules
  + Native log target support for systemd-journal
  + Many bug fixes
- Remove pulseaudio-revert-protocol-native.patch, included upstream
- Lower required alsa-lib version to 1.0.19
  (stated in notes for packagers)
* Wed Feb 26 2014 seife+obs@b1-systems.com
- relax the bluez dependency of pulseaudio-module-bluetooth from
  == bluez_version to >= bluez_version so that newer 3rd-party
  bluez builds (my testing builds e.g. :-) can be used
* Sun Feb 23 2014 zaitor@opensuse.org
- Update to version 4.99.4:
  + sink-input, source-output: Don't crash if format negotiation
    fails.
  + man:
  - pulse-cli-syntax: Document the "journal" log target.
  - Improve man page and help for cmdline options.
  + dbus: Use correct idxset when getting sources.
  + source: Increase max outputs per source
  + protocol-native: Fix a crash
  + thread-win32: Implement pa_thread_free_nojoin()
  + Updated translations.
- Add pulseaudio-revert-protocol-native.patch: Don't enumerate
  unlinked sinks and sources".
* Thu Jan 30 2014 oholecek@suse.cz
- update to version 5.0 RC3 (4.99.3)
- reenable orc
* Thu Jan 23 2014 dimstar@opensuse.org
- Update to version 5.0 RC2 (4.99.2):
  + This is finally an officially released tarball on the road to
    pulseaudio 5.0.
- Drop pulseaudio-introspect-Fix-ABI-break.patch: fixed upstream.
- Bump drvver to 4.99, following upstream.
- Pass --disable-orc to configure in order to avoid build failures
  due to orc files missing from the tarball.
- Drop call to autogen.sh: no longer required, as we are building a
  bootstrapped tarball.
* Mon Nov 25 2013 tiwai@suse.de
- pulseaudio-introspect-Fix-ABI-break.patch:
  Fix the incompatible size of pa_card_profile_info that leads to
  a crash of pavucontrol (bnc#851872)
* Sun Oct 20 2013 oholecek@suse.com
- enable bluez4 support for older openSUSE releases
* Fri Oct 18 2013 dimstar@opensuse.org
- Update to git master (PA 5.0) (4.0-270-g9490a):
  + alsa: fix crash when loading bare alsa sink (bnc#846532).
  + sndfile-util: fir format for 24bit depth wav files.
  + bluetooth: track discovery modules by index.
  + build system fixes.
* Sun Oct  6 2013 dimstar@opensuse.org
- Update to git mastere (PA 5.0 on the way) (265-g35fe):
  + The more extensive bluez5 branch was merged
  + PA allows to build bluez4 and bluez5 modules in parallel.
    Note: this does not mean that bluez4 and bluez5 can co-exist,
    only that PA can decide at runtime which bluez-daemon is
    available.
- Pass --disable-bluez4 to configure: we know that we run bluez5.
* Wed Sep 25 2013 dimstar@opensuse.org
- bnc#840845: Update to git master (PA 5.0 on the way) (6f94c).
  + Various code cleanups for inclusion of bluez5 stack.
- No longer pass --enable-bluez5 --disable-bluez4 to configure:
  master only speaks bluez5.
* Wed Sep 11 2013 mhrusecky@suse.cz
- support for system wide mode (separate subpackage with service)
* Sat Sep  7 2013 dimstar@opensuse.org
- Update to git snapshot (rev: gbf9b3)/ bluez5 branch.
  Note: this is not HEAD of the bluez5 branch, as in local tests,
  this did fail to load the bluetooth modules.
* Wed Aug 21 2013 dimstar@opensuse.org
- Fix fdupes call on doxygen/html: use hardlinks instead of
  softlinks (bnc#835683).
* Mon Jun 24 2013 oholecek@suse.com
- add SUSEfirewall service definition (bnc#607614)
* Thu Jun 13 2013 oholecek@suse.com
- require the same liborc version which was used to build against
* Mon Jun  3 2013 oholecek@suse.com
- update to pulseaudio 4.0
  * Better handling of low latency requests
  * Optimisations while mixing (generic, ARM NEON)
  * Default resampler is now speex-float-1 (lower CPU usage)
  * Major Bluetooth refactoring for better reliability and easier
  maintenance
  * Fixes for graceful hand-off to/from JACK
  * New module to apply ducking based on stream roles
  * Echo canceller infrastructure fixes
  * Bash and zsh completion for command line tools
  * Solaris and OS X fixes
  * Lots of other enhancements, bug fixes, and documenation and i18n
  updates-
* Thu Apr 25 2013 dmueller@suse.com
- explicitely disable building NEON for armv5/6
* Fri Mar  8 2013 tiwai@suse.de
- Fix a bug setting speaker volume to zero wrongly (bnc#805865)
* Tue Mar  5 2013 crrodriguez@opensuse.org
- remove fno-strict-aliasing from CFLAGS
- do not export SUSE_ASNEEDED=0, problem already fixed.
* Sun Jan 20 2013 oholecek@suse.com
- bluetooth module now requires Bluez > 4.99
* Mon Dec 31 2012 crrodriguez@opensuse.org
- Update to pulseaudio 3.0
  * ALSA Use Case Manager (UCM) support
  * Runtime editable LADSPA filter parameters
  * Out-of-the-box support for Bluetooth sources
  * Configurable device latency offset
  * Various ALSA changes
  * Lots of infrastructure improvements
* Tue Nov 27 2012 tiwai@suse.de
- Add the audio setup for qemu/kvm to setup-pulseaudio script
  (bnc#737070)
* Sat Nov 17 2012 crrodriguez@opensuse.org
- disable all HAL compat/support since it is long gone.
* Thu Nov 15 2012 tittiatcoke@gmail.com
- Enable systemd integration (following the distribution):
  + Add systemd-devel BuildRequires.
  + Pass --enable-systemd to configure.
* Sun Nov  4 2012 crrodriguez@opensuse.org
- Place udev rules in the proper place
* Tue Oct 16 2012 coolo@suse.com
- buildrequire systemd through pkgconfig provides to remove cycle
* Thu Sep  6 2012 tiwai@suse.de
- Fix the broken setup by setup-pulseaudio when alsa-plugins-pulse
  doesn't exist (bnc#779039)
* Sat Jul 21 2012 zaitor@opensuse.org
- Update to version 2.1:
  + Actually build libwebrtc-util.
  + Various bugfixes.
* Mon Jun 18 2012 tiwai@suse.de
- Add kmix setup to setup-pulseaudio script
* Wed Jun  6 2012 tiwai@suse.de
- Add the proper exit codes to setup-pulseaudio script
  (for avoiding the errors during installation, too)
* Mon Jun  4 2012 idonmez@suse.com
- Remove rpmlintrc, we can't use setBadness for Factory
* Wed May 30 2012 tiwai@suse.de
- Kill leftover PA processes when disabled via setup-pulseaudio
- Set up gstreamer audiosink/src in setup-pulseaudio script, too
* Tue May 29 2012 tiwai@suse.de
- Add the setup for SoX to setup-pulseaudio script
* Sat May 19 2012 pascal.bleser@opensuse.org
- update to 2.0:
  + Alternate sample rates.
  + Jack detection.
  + Echo cancellation: WebRTC canceller, automatic gain control,
    drift compensation.
  + Virtual Surround module.
  + Xen Paravirtualised audio sink.
  + Fixed HURD support.
  + A2DP decoder quality improvements.
- Add new BuildRequires: libwebrtc_audio_processing-devel,
  BuildRequires:  gcc-c++ and if SuSE-Release >= 12.1
  BuildRequires:  systemd-devel
- Drop pulseaudio-remove_broken_assert.patch, fixed upstream.
- Futureproof spec for soname changes.
* Fri Feb 17 2012 pascal.bleser@opensuse.org
- add pulseaudio-remove_broken_assert.patch to remove a broken assert that
  makes pulseaudio crash when playing audio from Firefox when having to
  resample, especially in combination with the jack sink
- add libcap-devel build dependency for capabilities support
- add fftw3-devel build dependency for builtin equalizer support
- add orc build dependency for better performance
* Thu Jan 12 2012 reddwarf@opensuse.org
- Remove libatomic-ops-devel buildrequires since it has been
  dropped from Factory (for x86/x86-64 it wasn't being used
  anyway)
* Tue Dec 27 2011 idonmez@suse.com
- Fix wrong size argument in memset call
* Fri Oct 21 2011 wstephenson@suse.com
- Update to version 1.1:
  + Reintroduce a 3 point version string in various API calls,
    fixing PulseAudio with Skype.
  + Fix some linking errors that accidentally linked libpulse to
    libpulsecore which could under some circumstance "downgrade"
    libpulse to GPL (rather than LGPL) which could in turn cause
    problems with non-GPL compatible apps which link to libpulse.
  + Fix a problem where starting PA without X11 would fail due to
    dbus problems.
* Fri Sep 30 2011 toddrme2178@gmail.com
- Made descriptions consistent
- Added %%suse_update_desktop_file for pulseaudio-kde
  (fix for RPMLINT warning)
- Added check for duplicate files (fix for RPMLINT warning)
- Cleaned up spec file formatting with spec-cleaner
* Tue Sep 27 2011 dimstar@opensuse.org
- Update to version 1.0:
  + Fix crash in threaded message queues
  + dbus: fix crash if modules do not load
- Changes from version 0.99.4:
  + Various bug fixes
- Changes from version 0.99.3:
  + Per-Port volume control
  + Fix Introspection annotations
  + Various bug fixes
- Add xz BuildRequires because we can't build a package for a
  xz-compressed tarball without explicitly specifying that... See
  bnc#697467 for more details
* Thu Aug 25 2011 dimstar@opensuse.org
- Update to version 0.99.2 (2nd pre-release of 1.0):
  + D-Bus based control protocol (beta)
  + Source Output Volumes
  + Passthrough Support
  + Windows support restored
  + Improved sample rate adaptation in module-rtp-receive
  + Volume Change Sync for flat volumes
  + Enhanced Port Volume controls
  + New, future proof format for metadata files
  + New equalizer and acoustic echo cancellation modules
  + If Jack is running, Pulseaudio will connect to it automatically
    by default (previously this required editing a configuration
    file)
- Add pkgconfig(json) BuildRequires.
- Rebase disabled-start.diff and suppress-socket-error-msg.diff.
* Wed Jul 27 2011 tiwai@suse.de
- Updated to version 0.9.23:
  Bugfix only update, see changelog at
    http://pulseaudio.org/milestone/0.9.23
- Suppress too verbose error message at socket connection failure
  from a client; this is annoying when alsa-plugins-pulse fallback
  is used
* Fri Jul 22 2011 vuntz@opensuse.org
- Automatically configure the system for pulseaudio in %%post:
  + Note that this change will forcefully enable PulseAudio on
    systems where it had manually been disabled with
    "setup-pulseaudio --disable" but without adding
    PULSEAUDIO_ENABLE="no" to /etc/sysconfig/sound.
  + Install sysconfig.sound-pulseaudio template, and use fillup in
    %%post to merge it in /etc/sysconfig/sound. Add %%fillup_prereq
    PreReq for this.
  + This defines the PULSEAUDIO_ENABLE variable that can be set to
    "yes", "no", "custom" (which means that the user has manually
    changed the configuration). Set to "yes" by default.
  + Add --auto option setup-pulseaudio: this automatically
    enables (resp. disables) pulseaudio if PULSEAUDIO_ENABLE is set
    to "yes" (resp. "no"). It does nothing if PULSEAUDIO_ENABLE is
    set to "custom".
  + Call "setup-pulseaudio --auto" in %%post.
  + This fixes bnc#707703.
- Remove call to /sbin/SuSEconfig in setup-pulseaudio: it should
  not be needed.
- Use sed instead of perl in setup-pulseaudio: this avoids leaving
  empty lines when removing a line from the configuration.
* Mon Mar 21 2011 tiwai@suse.de
- Fix handling of /etc/mplayer/mplayer.conf in setup-pulseaudio
  script (bnc#681113)
* Thu Feb 17 2011 tiwai@suse.de
- Add the setup for festival to setup-pulseaudio script
  (bnc#670992)
* Mon Feb 14 2011 sbrabec@suse.cz
- Added support for translation-update-upstream.
* Sat Jan 22 2011 sreeves@novell.com
- Add bnc666350-fix-incorrect-check-of-return-value.patch
- Fix ownership of /var/lib/gdm for bnc#638052
* Fri Nov 26 2010 dimstar@opensuse.org
- Update to version 0.9.22:
  + This release contains the list of patches we carried plus a few
    more bugfixes.
- Drop patches [0001 - 0063] that were backported from git.
* Tue Sep 28 2010 aj@suse.de
- Recommend instead of require lang-package.
* Thu Aug 12 2010 tiwai@suse.de
- minor fixes for setup-pulseaudio (bnc#623837)
  also added /etc/profile.d/pulseaudio.* to file list as ghost
* Tue Jul 20 2010 tiwai@suse.de
- set up sh/csh profiles instead of /etc/environment in
  setup-pulseaudio script (bnc#623837)
* Tue Jul 20 2010 tiwai@suse.de
- Add speechd setup to setup-pulseaudio (bnc#619859)
- Use grep -q for testing in setup-pulseaudio
* Sat May 15 2010 coolo@novell.com
- the gdm is not needed during build, so ignore it and avoid huge
  build cycle
* Thu Apr  8 2010 sreeves@novell.com
- Add Requires of pulseaudio-utils to pulseaudio-module-x11
  Fix bnc#592155
* Tue Apr  6 2010 ro@suse.de
- add libpulse-mainloop-glib0 to baselibs.conf (for libphonon4)
* Mon Mar 29 2010 per@osbeck.com
- add support for phonon in setup-pulseaudio
* Mon Mar  8 2010 sreeves@novell.com
- Add 0063-core-util-ensure-that-we-chmod-only-the-dir-we-ours.patch
    Fix bnc#584938 - chmod only the dir we ourselves created.
* Mon Mar  1 2010 sreeves@novell.com
- Add another set of patches backported from upstream git
    [0033 - 0062].patch
    Fixes for latency settings, cpu utilization, stuck playback,...
* Tue Jan 19 2010 sreeves@novell.com
- Add set of patches backported from upstream git
    [0001 - 0032].patch
- Remove pulseaudio-ticket738-mark-shared-vars-as-volatile.patch
    Included in set of patches above
* Mon Jan 11 2010 sreeves@novell.com
- Add pulseaudio-ticket738-mark-shared-vars-as-volatile.patch
- Move start-pulseaudio-kde to pulseaudio-module-x11. Match upstream
- Modify disabled-start.diff
    Add check for pulseaudio_enable in start-pulseaudio-kde
* Fri Dec 18 2009 jengelh@medozas.de
- Add baselibs.conf as a source
* Thu Dec  3 2009 dimstar@opensuse.org
- Update to version 0.9.21:
  + Bugfix update - see ChangeLog for full details.
* Tue Nov  3 2009 sreeves@novell.com
- Fix mplayer section of setup-pulseaudio. bnc#547384
* Thu Oct 29 2009 lnussel@suse.de
- clean up and fix setup-pulseaudio to not corrupt /etc/environment
  (bnc#547384)
* Tue Oct  6 2009 sreeves@novell.com
- Update to 0.9.19
    Bugfix update - see Changelog for full details
* Mon Sep 28 2009 llunak@novell.com
- make 'setup-pulseaudio --disable' actually really disable PA (bnc#537780)
* Thu Sep 24 2009 sreeves@novell.com
- Update to 0.9.18
    Bugfix update - see Changelog for full details
    Translation update.
* Fri Sep 18 2009 sreeves@novell.com
- Update to 0.9.17
  Fix tsched usage that was broken in 0.9.16
* Thu Sep 10 2009 sreeves@novell.com
- Update to 0.9.16
  Please see Changelog for full details
* Mon Sep  7 2009 coolo@novell.com
- do not require a kernel, self compiled kernels will work with
  pulseaudio too. Conflict with old kernels instead
* Wed Sep  2 2009 sreeves@novell.com
- Update to version 0.9.16-test7
  Please see Changelog for full details
- Remove uneeded patches (functionality  already in 0.9.16)
    set of recommended backported patches (00*.patch)
    pulseaudio-am111.patch
    pulseaudio-bnc480113-default-sink.patch
- Remove pulseaudio-work-with-old-alsa.patch
- Add package pulseaudio-gdm-hooks
* Mon Aug 24 2009 coolo@novell.com
- provide new esound-daemon, but only obsolete old versions (of < 11.1)
  fix for bnc#532838
* Thu Jul 30 2009 sbrabec@suse.cz
- pulseaudio-utils have no use without pulseaudio, add Requires.
* Wed Jul 22 2009 sreeves@novell.com
- Add a set of recommended backported patches from git master
* Mon Jul 20 2009 dominique-obs@leuenberger.net
- Fix remainings to follow %%%%{_libexecdir} change
* Fri Jul 17 2009 coolo@novell.com
- build with automake 1.11
* Fri Jul 17 2009 coolo@novell.com
- disable as-needed to fix build
* Fri Jul 17 2009 coolo@novell.com
- udev-extras is dropped again
* Tue May 12 2009 sreeves@novell.com
- Packaging changes:
  + add udev-extras to buildRequires
  + Only require alsa 1.0.18 as that version is patched on
    11.1 to have needed functionality of 1.0.19
    (pulseaudio-work-with-old-alsa.patch)
* Thu Apr 30 2009 sbrabec@suse.cz
- Don't call autoreconf in older products.
- Don't try to package PolicyKit files in older products.
* Fri Apr 24 2009 sreeves@novell.com
- Update to version 0.9.15:
  Please see Changelog for full details
- Add more checks for "Digital" output for choosing default sink
  (pulseaudio-bnc480113-default-sink.patch)
- Drop pulseaudio-defaults-daemon-conf.patch: use upstream defaults
  for default-fragments* in daemon.conf
- Packaging changes:
  + Move libpulsecore into main rpm as it's an internal only
    library
  + Remove unused old replacment for default.pa
  + Move start-pulseaudio-x11 into pulseaudio-module-x11 package
* Wed Mar 25 2009 sreeves@suse.de
- Fix for bnc#480113 - default sink
- Fix for bnc#456802 - logging out of control
* Thu Feb 26 2009 sreeves@suse.de
- Fix for bnc#464994 - error messages when using pulse
- Fix for bnc#461361 - sound crackles
- Fix for bnc#469886 - HDMI sound is muted
* Tue Feb 10 2009 vuntz@novell.com
- Update Provides/Obsoletes version for esound-daemon.
* Sat Jan 24 2009 vuntz@novell.com
- Rename libpulse8 to libpulse9 because of soname change, to fix
  the build.
- Add a lang package.
- Use %%suse_update_desktop_file for pulseaudio.desktop.
* Fri Jan 23 2009 rodrigo@novell.com
- Remove perl-XML-Parser from BuildRequires
* Thu Jan 15 2009 rodrigo@novell.com
- Update to version 0.9.14:
  + All bug fixes included in the 0.9.13 Fedora package
- Depend on libavahi-devel
* Thu Jan  1 2009 mboman@suse.de
- Update to version 0.9.13:
  + Too many fixes/update to list. Please see Changelog for full details
- Remove pulseaudio-dot-pulse.patch. Fixed upstream
- Remove pulseaudio-allow-in-sample-names.patch. Fixed upstream
- Remove pulseaudio-asserts.patch. Fixed upstream
* Thu Dec  4 2008 rodrigo@novell.com
- Renamed libpulsecore4 to libpulsecore7 to match so version
  (bnc#456053)
* Mon Nov 24 2008 rodrigo@novell.com
- Use /etc/alsa-pulse.conf for ALSA when enabling PulseAudio, as we
  already do in GNOME, instead of touching /etc/alsa.conf
- Don't run the script if user is not root (bnc#445997)
* Wed Nov 19 2008 rodrigo@novell.com
- Some fixes in setup-pulseaudio script (bnc#445015)
* Wed Nov 19 2008 rodrigo@novell.com
- Add upstream patch for bnc#443510
* Tue Nov 11 2008 rodrigo@novell.com
- Add upstream patch for bnc#439054
* Mon Oct 27 2008 rodrigo@novell.com
- Fixed some bugs in setup-pulseaudio script (bnc#425475)
* Thu Oct 16 2008 maw@novell.com
- Run autoreconf.
* Sat Sep 20 2008 rodrigo@suse.de
- Added pulseaudio-dot-pulse.patch from upstream to fix broken
  ~/.pulse directory creation (bnc#427859)
- Added setup-pulseaudio script (bnc#425475)
* Tue Sep 16 2008 kukuk@suse.de
- Only include locales, no directories
* Mon Sep 15 2008 dmueller@suse.de
- adjust buildrequires
* Thu Sep 11 2008 rodrigo@suse.de
- Added unpackaged files.
- Removed non exiting files.
* Thu Sep 11 2008 rodrigo@suse.de
- Added missing dependency on intltool
- Removed unneeded patch
- Update to 0.9.12 version:
  + If a mixer device only supports a limited dB range, extend it in
    software
  + Reworked state/runtime directory selection
  + A few inner loops have been optimized
  + The PA native protocol may now be extended by modules
  + A new module module-stream-restore with a client interface, which
    is intended to replace module-volume-restore (which however will
    stay around for compatibility with old configurations)
  + Allow global glitch-free mode setting in module-hal ("tsched=")
  + Internationalization
  + Rewritten autospawning logic
  + A lot of bugfixes, other improvements
* Sun Aug 17 2008 ro@suse.de
- change version number for esound-daemon provides to current
  esound version
* Mon Aug 11 2008 rodrigo@suse.de
- Change Obsoletes and Provides from esound to esound-daemon, which
  is the new package containing the Esound daemon
* Wed Jul 16 2008 rodrigo@suse.de
- Update to 0.9.11-RC version:
  + Much better sound latency implementation (glitch-free)
  + New driven main loop
  + Additional stream attributes for libcanberra
- Added new BuildRequires
- Added new modules to list of installed files
* Fri Jun 27 2008 maw@suse.de
- Own some directories so that builds succeed.
* Tue Jun 24 2008 rodrigo@suse.de
- Added .desktop file for autostarting under GNOME (bnc#387052)
* Sat May 31 2008 rodrigo@suse.de
- Don't require alsa-plugins-pulse, just Recommend it (bnc#394177)
* Mon May 26 2008 rodrigo@suse.de
- Depend on alsa-plugins-pulse to have ALSA-based applications
  work out of the box with PulseAudio (bnc#394177)
* Fri May 23 2008 jpr@suse.de
- Generate 32bit libraries (bnc #338269)
* Mon May 19 2008 rodrigo@suse.de
- Removed pulseaudio-use-correct-socket-for-esd-375701.patch,
  which conflicts with esound patch (bnc#391864)
* Mon May 12 2008 rodrigo@suse.de
- Added pulseaudio-defaults-daemon-conf.patch to set default
  values for better performance (bnc#381686)
* Tue May  6 2008 rodrigo@suse.de
- Added pulseaudio-use-correct-socket-for-esd-375701.patch to
  use correct esound socket (bnc375701)
* Wed Apr  9 2008 maw@suse.de
- Update to version 0.9.10:
  + Better compatibility in padsp with certain programs which like
    to pass NULL strings to libc functions
  + Properly create ~/.pulse before using it
  + Multiarch fixes
  + Update module-tunnel for protocol version 12
  + Update Speex resampler
  + Native ARM atomic operations support
  + Update of the PolicyKit interface
  + Compatibility with libtool 2.2
  + LADSPA interfacing fixes
  + Make per-user esd socket compile time configurable
  + Many other bug fixes and updates
- Drop pulseaudio-0.9.8-fix-sample-upload.patch
- Add pulseaudio-declarations.patch.
* Fri Apr  4 2008 rodrigo@suse.de
- Added Obsoletes and Provides to esound-compat package to fix
  dependencies on esound
* Wed Mar 12 2008 rodrigo@suse.de
- Review and merge changes from public build service into FACTORY.
* Sun Mar  9 2008 cyberorg@cyberorg.info
- Update to 0.9.9
- The only change from 0.9.8 is a fix for CVE-2008-0008
- Need to add pulse user to audio group too
* Fri Jan 25 2008 rodrigo@suse.de
- Removed empty patch file
- Disabled setuid binaries
* Thu Jan 24 2008 rodrigo@suse.de
- Don't use our own default configuration, use upstream one. This
  should give us support for all devices detected by HAL.
* Wed Jan 23 2008 rodrigo@suse.de
- Reviewed changes from cyberorg@cyberorg.info submitted to
  home:rodrigomoya:pulseaudio BS service.
* Thu Jan 10 2008 cyberorg@cyberorg.info
- Update to 0.9.8
  * Man pages
  * Make real-time priority and nice level configurable
  * Support acquiring priviliges for high-priority and real-time scheduling
    via PolicyKit
  * Support S32 samples natively
  * Rework ALSA surround sound configuration completely
  * Automatic upmixing/downmixing
  * Add a couple of new directives to libpulse: add flag to allow fixing the
    sample specs to the ones that are native to the sink/source a stream is
    connected to; Change the sample rate, buffering attributes during runtime;
    allow notification on device suspend/resume and moving of streams between
    devices
  * Check process name when dealing with PID files
  * Allow configuratin of RLIMIT_RTPRIO, RLIMIT_NICE
  * Add bluetooth proximity module. Just pair your phone and have PA turn down
    the volume when you leave with your phone and turn it up again if you come back.
- Enable bluetooth
- Enable Jack
- Add policykit
- Add many man pages
- Enable tcpd
* Wed Jan  9 2008 rodrigo@suse.de
- Renamed libs packages to follow shared lib policy
- Added better descriptions for subpackages
- Use tar.bz2 instead of tar.gz
- Fixed unversioned self-provides and obsoletes
- Use update-desktop-files for .desktop file
- PreRequire pwdutils for groupadd/del
- Moved libpulsedsp.so to libpusecore4 to avoid rpmlint errors
* Tue Jan  8 2008 rodrigo@suse.de
- Don't remove users/groups on %%postun
* Tue Jan  8 2008 rodrigo@suse.de
- Removed 'rm -rf $RPM_BUILD_ROOT' from %%install
* Mon Dec 24 2007 rodrigo@suse.de
- Use /var/lib/pulseaudio as home dir for pulseaudio user.
* Tue Dec 11 2007 rodrigo@suse.de
- Removed special permissions for pulseaudio binary to make it
  buildable until the permissions thing is solved.
* Tue Dec 11 2007 rodrigo@suse.de
- Merged with package from home:rodrigomoya:pulseaudio BS project.
* Thu Nov 22 2007 cyberorg@cyberorg.info
- Remove Provides and Obsoletes from esound compat package
* Wed Nov 21 2007 cyberorg@cyberorg.info
- Restructured spec file to build more subpackages, like in Fedora 8.
* Wed Oct 31 2007 tiwai@suse.de
- updated to version 0.9.7:
  * New threaded lock-free (mostly at least) core
  * New module for automatic discovery of zeroconf audio devices
  * Reworked JACK module for better real-time compatibility
  * PA now suspends access to all audio devices if idle
  * module-combine is now beefedup to automatically pick up local hw devices
  * make use of gcc intrinsics for atomic ops, byteswap, tls, where possible
  * use speex resampler by default
  * use mmap access by default for ALSA devices
  * fold OSS mmap driver into normal OSS driver
  * add LADSPA plugin
  * add plugin for splitting or remapping channel maps
  * Use Linux eventfd() if available, instead of hacks around FIFOs
  * make use of PTHREAD_PRIO_INHERIT for some mutexes, wher it makes sense
  * cleanup dead SHM frags from /dev/shm, where applicable
  * automatically store/restore default audio device
  * add new tool pasuspender tool
  * X11 session management support
  * allow global configuration for fragment settings/sizes
  * PA (if HAL is enabled) now ignores modem sound devices by default
  * Lots of bug fixes and other improvements
* Thu Oct 11 2007 sbrabec@suse.cz
- Use binding specific avahi package.
* Tue Jun 19 2007 tiwai@suse.de
- fixed default.pa (typo of rtp.monitor).
* Tue Jun 12 2007 tiwai@suse.de
- disable flist-test that doesn't pass with ppc (libatomic-ops
  problem)
* Fri Jun  8 2007 tiwai@suse.de
- updated to version 0.9.6:
  * bugfixes, including previous patches
  * use lock-free algorith with libatomic-ops
- add avahi-devel, xorg-x11-devel, glib2-devel and hal-devel to
  buildrequires
- prefer Master volume to PCM volume
* Tue May 29 2007 tiwai@suse.de
- fix possible remote DoS (#260326)
- fix wrong endian conversion of float data
- add a workaround for firefox with LD_PRELOAD wrapper
- add the missing support of ioctls for JavaSound
- increase ESD max samplesize
* Tue Apr 24 2007 tiwai@suse.de
- disable static library, don't use ltdl install
- fix requires of devel package
- fix post and postun
- build documents via doxygen
- fix suspend/resume with alsa backend
- fix the frame size handling in alsa backend
- fix possible NULL dereference
* Sun Oct 15 2006 schwab@suse.de
- Make sure config.rpath is present.
* Wed Sep  6 2006 tiwai@suse.de
- updated to version 0.9.5:
  * add module-hal-detect module
  * shared memory transfer method for local clients
  * update module-volume-restore to automatically restore the output device
  * add a new module module-rescue-streams
  * add support for moving streams "hot" between sinks/sources
  * reduce memory consumption and CPU load
  * add new module module-gconf for reading additional configuration
  * fix module-tunnel to work with the latest protocol
  * miscellaneous fixes
* Thu Aug 17 2006 tiwai@suse.de
- move libpulsedsp.so to the main package from devel sub package
  (#199735).
* Mon Jul 31 2006 tiwai@suse.de
- updated to version 0.9.4:
  * support for system-wide pulseaudio daemon.
  * add authentication by IP address range ACL (auth-ip-acl=)
  * support to set resource limits on platforms
  * remove loopback= argument for module-*-protocol-tcp
  * remove obsolete GLIB event loop adapter
  * add an API to check whether a source/sink is hardware or virtual
  * remove warning about SIGPIPE in client apps
  * improve latency calculation of NULL sink
  * port Zeroconf code from the HOWL API to the native Avahi API
  * fix broken time event handling in GLIB
  * Some valgrind/massif fixes
  * Fix pkg-config files for AMD64
* Wed Jul 12 2006 tiwai@suse.de
- renamed from polypaudio to pulseaudio (the project name was
  changed)
- update to version 0.9.2:
  * increase maximum number of concurrent connections
  * fix latency interpolation
  * add support for reverse endian sound cards
  * add support for recording in padsp
  * reenable CPU load limiter
  * other bugfixes
